@@ -28,7 +28,8 @@ from sphinxcontrib.autodoc_pydantic.util import (
     option_one_of_factory,
     option_default_true,
     option_list_like,
-    PydanticAutoDoc
+    PydanticAutoDoc,
+    NONE
 )
 
 OPTION_SPEC_FIELD = {
@@ -135,16 +136,23 @@ class PydanticModelDocumenter(ClassDocumenter):
         super().__init__(*args)
         self.pyautodoc = PydanticAutoDoc(self)
 
+    def document_members(self, *args, **kwargs):
+        """Modify member options before starting to document members.
+
+        """
+
         self.pyautodoc.set_default_option_with_value("members", ALL)
         if self.options.get("undoc-members") is False:
             self.options.pop("undoc-members")
 
-        if not self.pyautodoc.get_option_value("show-config-member", True):
+        if self.pyautodoc.option_is_false("show-config-member", True):
             self.hide_config_member()
 
-        if not self.pyautodoc.get_option_value("show-validator-members", True):
+        if self.pyautodoc.option_is_false("show-validator-members", True):
             self.hide_validator_members()
 
+        super().document_members(*args, **kwargs)
+
     def hide_config_member(self):
         """Add `Config` to `exclude_members` option.
 
@@ -160,9 +168,7 @@ class PydanticModelDocumenter(ClassDocumenter):
 
         """
 
-        obj = self.pyautodoc.get_pydantic_object_from_name()
-
-        validators = ModelWrapper(obj).get_validator_names()
+        validators = ModelWrapper(self.object).get_validator_names()
         if "exclude-members" not in self.options:
             self.options["exclude-members"] = validators
         else:
@@ -173,7 +179,7 @@ class PydanticModelDocumenter(ClassDocumenter):
 
         """
 
-        if self.pyautodoc.get_option_value("hide-paramlist", True):
+        if self.pyautodoc.option_is_true("hide-paramlist", True):
             return ""
         else:
             return super().format_signature(**kwargs)
@@ -188,13 +194,13 @@ class PydanticModelDocumenter(ClassDocumenter):
 
         super().add_content(more_content, no_docstring)
 
-        if self.pyautodoc.get_option_value("show-json", True):
+        if self.pyautodoc.option_is_true("show-json", True):
             self.add_collapsable_schema()
 
-        if self.pyautodoc.get_option_value("show-config-summary", True):
+        if self.pyautodoc.option_is_true("show-config-summary", True):
             self.add_config_summary()
 
-        if self.pyautodoc.get_option_value("show-validator-summary", True):
+        if self.pyautodoc.option_is_true("show-validator-summary", True):
             self.add_validators_summary()
 
     def add_collapsable_schema(self):
@@ -341,7 +347,7 @@ class PydanticFieldDocumenter(AttributeDocumenter):
         """
 
         super().add_directive_header(sig)
-        if self.pyautodoc.get_option_value("field-show-default"):
+        if self.pyautodoc.option_is_true("field-show-default"):
             self.add_default_value()
 
     def add_default_value(self):
@@ -366,15 +372,15 @@ class PydanticFieldDocumenter(AttributeDocumenter):
         """
 
         doc_policy = self.pyautodoc.get_option_value("field-doc-policy")
-        if doc_policy in ("docstring", "both", None):
+        if doc_policy in ("docstring", "both", None, NONE):
             super().add_content(more_content, no_docstring)
         if doc_policy in ("both", "description"):
             self.add_description()
 
-        if self.pyautodoc.get_option_value("field-show-constraints"):
+        if self.pyautodoc.option_is_true("field-show-constraints"):
             self.add_constraints()
 
-        if self.pyautodoc.get_option_value("field-list-validators"):
+        if self.pyautodoc.option_is_true("field-list-validators"):
             self.add_validators()
 
     def add_constraints(self):
@@ -473,7 +479,7 @@ class PydanticValidatorDocumenter(MethodDocumenter):
 
         """
 
-        if self.pyautodoc.get_option_value("validator-replace-signature"):
+        if self.pyautodoc.option_is_true("validator-replace-signature"):
             return ''
         else:
             return super().format_args(**kwargs)
@@ -488,7 +494,7 @@ class PydanticValidatorDocumenter(MethodDocumenter):
 
         super().add_content(more_content, no_docstring)
 
-        if self.pyautodoc.get_option_value("validator-list-fields"):
+        if self.pyautodoc.option_is_true("validator-list-fields"):
             self.add_field_list()
 
     def add_field_list(self):
